@@ -1,51 +1,51 @@
-#' Frequentist and Bayesian Planning for Audit Sampling
+#' Plan a statistical audit sample
 #'
-#' @description This function calculates the required sample size for an audit, based on the Poisson, binomial or hypergeometric likelihood. A prior distribution can be specified to perform Bayesian planning. The returned object is of class \code{jfaPlanning} and has a \code{print()} and \code{plot()} method.
+#' @description This function calculates the minimum sample size for a statistical audit sample based on the Poisson, binomial or hypergeometric likelihood. The function returns an object of class \code{jfaPlanning} which can be used with associated \code{print()} and \code{plot()} methods.
 #'
-#' For more details on how to use this function see the package vignette:
+#' For more details on how to use this function, see the package vignette:
 #' \code{vignette('jfa', package = 'jfa')}
 #'
-#' @usage planning(confidence = 0.95, expectedError = 0, likelihood = 'poisson', N = NULL, 
-#'           materiality = NULL, minPrecision = NULL, 
-#'           prior = FALSE, nPrior = 0, kPrior = 0,
-#'           increase = 1, maxSize = 5000)
+#' @usage planning(confidence, materiality = NULL, minPrecision = NULL,
+#'          expectedError = 0, likelihood = 'binomial', N = NULL,
+#'          prior = FALSE, nPrior = 0, kPrior = 0,
+#'          increase = 1, maxSize = 5000)
 #'
-#' @param confidence    a value between 0 and 1 specifying the confidence level desired for the sample planning. Defaults to 0.95 for 95\% confidence.
-#' @param expectedError a value between 0 and 1 specifying the expected errors in the sample relative to the total sample size, or a number (>= 1) that represents the number of expected errors in the sample. It is advised to set this value conservatively to minimize the probability of the observed errors exceeding the expected errors, which would imply that insufficient work has been done in the end.
+#' @param confidence    a numeric value between 0 and 1 specifying the confidence level used in the planning.
+#' @param materiality   a numeric value between 0 and 1 specifying the performance materiality (i.e., maximum upper limit) as a fraction of the total population size. Can be \code{NULL}, but \code{minPrecision} should be specified in that case.
+#' @param minPrecision  a numeric value between 0 and 1 specifying the minimum precision (i.e., upper bound minus most likely error) as a fraction of the total population size. Can be \code{NULL}, but \code{materiality} should be specified in that case.
+#' @param expectedError a numeric value between 0 and 1 specifying the expected errors in the sample relative to the total sample size, or a number (>= 1) that represents the number of expected errors in the sample. It is advised to set this value conservatively to minimize the probability of the observed errors exceeding the expected errors, which would imply that insufficient work has been done in the end.
 #' @param likelihood    a character specifying the likelihood assumed in the calculation. This can be either \code{binomial} for the binomial likelihood, \code{poisson} for the Poisson likelihood, or \code{hypergeometric} for the hypergeometric likelihood. See the details section for more information about the available likelihoods.
-#' @param N             an integer (or value) larger than 0 specifying the total population size (or value). Only required when \code{likelihood = 'hypergeometric'}.
-#' @param materiality   a value between 0 and 1 specifying the performance materiality (i.e., maximum upper limit) of the audit as a fraction of the total size (or value). Can be \code{NULL}, but \code{minPrecision} should be specified in that case.
-#' @param minPrecision  a value between 0 and 1 specifying the minimum precision (i.e., upper bound minus most likely error) to be obtained. Can be \code{NULL}, but \code{materiality} should be specified in that case.
-#' @param prior         a logical specifying whether to use a prior distribution when planning, or an object of class `jfaPrior` containing the prior distribution. Defaults to \code{FALSE} for frequentist planning. If \code{TRUE}, a negligible prior distribution is chosen by default, but can be adjusted using the `kPrior` and `nPrior` arguments. Chooses a conjugate gamma distribution for the Poisson likelihood, a conjugate beta distribution for the binomial likelihood, and a conjugate beta-binomial distribution for the hypergeometric likelihood.
-#' @param nPrior        if \code{prior = TRUE}, a value larger than, or equal to, 0 specifying the number of sampling units in the implicit sample on which the prior distribution is based.
-#' @param kPrior        if \code{prior = TRUE}, a value larger than, or equal to, 0 specifying the assumed sum of errors in the implicit sample on which the prior distribution is based.
+#' @param N             an integer larger than 0 specifying the total population size. Only required when \code{likelihood = 'hypergeometric'}.
+#' @param prior         a logical specifying whether to use a prior distribution when planning, or an object of class \code{jfaPrior} containing the prior distribution. Defaults to \code{FALSE} for frequentist planning. If \code{TRUE}, a negligible prior distribution is chosen by default, but can be adjusted using the \code{kPrior} and \code{nPrior} arguments. Chooses a conjugate gamma distribution for the Poisson likelihood, a conjugate beta distribution for the binomial likelihood, and a conjugate beta-binomial distribution for the hypergeometric likelihood.
+#' @param nPrior        if \code{prior = TRUE}, a numeric value larger than, or equal to, 0 specifying the sample size of the sample equivalent to the prior information.
+#' @param kPrior        if \code{prior = TRUE}, a numeric value larger than, or equal to, 0 specifying the sum of errors in the sample equivalent to the prior information.
 #' @param increase      an integer larger than 0 specifying the desired increase step for the sample size calculation.
 #' @param maxSize       an integer larger than 0 specifying the maximum sample size that is considered in the calculation. Defaults to 5000 for efficiency. Increase this value if the sample size cannot be found due to it being too large (e.g., for a low materiality).
 #' 
 #' @details This section elaborates on the available likelihoods and corresponding prior distributions for the \code{likelihood} argument.
 #' 
 #' \itemize{
-#'  \item{\code{poisson}:          The Poisson likelihood is used as a likelihood for monetary unit sampling (MUS). Its likelihood function is defined as: \deqn{p(x) = \frac{\lambda^x e^{-\lambda}}{x!}} The conjugate \emph{gamma(\eqn{\alpha, \beta})} prior has probability density function: \deqn{f(x; \alpha, \beta) = \frac{\beta^\alpha x^{\alpha - 1} e^{-\beta x}}{\Gamma(\alpha)}}}
-#'  \item{\code{binomial}:         The binomial likelihood is used as a likelihood for record sampling \emph{with} replacement. Its likelihood function is defined as: \deqn{p(x) = {n \choose k} p^k (1 - p)^{n - k}} The conjugate \emph{beta(\eqn{\alpha, \beta})} prior has probability density function: \deqn{f(x; \alpha, \beta) = \frac{1}{B(\alpha, \beta)} x^{\alpha - 1} (1 - x)^{\beta - 1}}}
-#'  \item{\code{hypergeometric}:   The hypergeometric likelihood is used as a likelihood for record sampling \emph{without} replacement. Its likelihood function is defined as: \deqn{p(x = k) = \frac{{K \choose k} {N - K \choose n - k}}{{N \choose n}}} The conjugate \emph{beta-binomial(\eqn{\alpha, \beta})} prior (Dyer and Pierce, 1993) has probability density function: \deqn{f(k | n, \alpha, \beta) = {n \choose k} \frac{B(k + \alpha, n - k + \beta)}{B(\alpha, \beta)}} }
+#'  \item{\code{binomial}:         The binomial likelihood is often used as a likelihood for attributes sampling \emph{with} replacement. The likelihood function is defined as: \deqn{p(x) = {n \choose k} p^k (1 - p)^{n - k}} The conjugate \emph{beta(\eqn{\alpha, \beta})} prior has probability density function: \deqn{f(x; \alpha, \beta) = \frac{1}{B(\alpha, \beta)} x^{\alpha - 1} (1 - x)^{\beta - 1}}}
+#'  \item{\code{poisson}:          The Poisson likelihood is often used as a likelihood for monetary unit sampling (MUS). The likelihood function is defined as: \deqn{p(x) = \frac{\lambda^x e^{-\lambda}}{x!}} The conjugate \emph{gamma(\eqn{\alpha, \beta})} prior has probability density function: \deqn{f(x; \alpha, \beta) = \frac{\beta^\alpha x^{\alpha - 1} e^{-\beta x}}{\Gamma(\alpha)}}}
+#'  \item{\code{hypergeometric}:   The hypergeometric likelihood is used as a likelihood for sampling \emph{without} replacement. The likelihood function is defined as: \deqn{p(x = k) = \frac{{K \choose k} {N - K \choose n - k}}{{N \choose n}}} The conjugate \emph{beta-binomial(\eqn{\alpha, \beta})} prior (Dyer and Pierce, 1993) has probability density function: \deqn{f(k | n, \alpha, \beta) = {n \choose k} \frac{B(k + \alpha, n - k + \beta)}{B(\alpha, \beta)}} }
 #' }
 #'
 #' @return An object of class \code{jfaPlanning} containing:
 #' 
-#' \item{confidence}{a value between 0 and 1 indicating the confidence level.}
-#' \item{expectedError}{a value larger than, or equal to, 0 indicating the expected errors input.}
+#' \item{confidence}{a numeric value between 0 and 1 indicating the confidence level.}
+#' \item{materiality}{a numeric value between 0 and 1 indicating the specified materiality. Can be \code{NULL}.}
+#' \item{minPrecision}{a numeric value between 0 and 1 indicating the minimum precision to be obtained. Can be \code{NULL}.}
+#' \item{expectedError}{a numeric value larger than, or equal to, 0 indicating the expected errors input.}
 #' \item{likelihood}{a character indicating the specified likelihood.}
 #' \item{N}{an integer larger than 0 indicating the population size (only returned if \code{N} is specified).}
-#' \item{materiality}{a value between 0 and 1 indicating the specified materiality. Can be \code{NULL}.}
-#' \item{minPrecision}{a value between 0 and 1 indicating the minimum precision to be obtained. Can be \code{NULL}.}
 #' \item{sampleSize}{an integer larger than 0 indicating the required sample size.}
 #' \item{errorType}{a character indicating whether the expected errors where specified as a percentage or as an integer.}
-#' \item{expectedSampleError}{a value larger than, or equal to, 0 indicating the number of errors that are allowed in the sample.}
-#' \item{expectedBound}{a value between 0 and 1 indicating the expected upper bound if the sample goes according to plan.}
-#' \item{expectedPrecision}{a value between 0 and 1 indicating the expected precision if the sample goes according to plan.}
+#' \item{expectedSampleError}{a numeric value larger than, or equal to, 0 indicating the number of errors that are allowed in the sample.}
+#' \item{expectedBound}{a numeric value between 0 and 1 indicating the expected upper bound if the sample goes according to plan.}
+#' \item{expectedPrecision}{a numeric value between 0 and 1 indicating the expected precision if the sample goes according to plan.}
 #' \item{populationK}{if \code{likelihood = 'hypergeometric'}, an integer larger than 0 indicating the assumed population errors.}
-#' \item{prior}{if a prior distribution is specified, an object of class \code{jfaPrior} that contains the prior distribution.}
-#' \item{expectedPosterior}{if a prior distribution is specified, an object of class \code{jfaPosterior} that contains the expected posterior distribution.}
+#' \item{prior}{if a prior distribution is specified, an object of class \code{jfaPrior} that contains information about the prior distribution.}
+#' \item{expectedPosterior}{if a prior distribution is specified, an object of class \code{jfaPosterior} that contains information about the expected posterior distribution.}
 #'
 #' @author Koen Derks, \email{k.derks@nyenrode.nl}
 #'
@@ -53,78 +53,21 @@
 #'
 #' @references Dyer, D. and Pierce, R.L. (1993). On the choice of the prior distribution in hypergeometric sampling. \emph{Communications in Statistics - Theory and Methods}, 22(8), 2125 - 2146.
 #'
-#' @examples
-#' library(jfa)
-#' 
-#' # Using the binomial distribution, calculates the required sample size for a 
-#' # materiality of 5% when 2.5% mistakes are expected to be found in the sample.
-#' 
-#' # Frequentist planning with binomial likelihood:
-#' 
-#' p1 <- planning(confidence = 0.95, expectedError = 0.025, likelihood = 'binomial',
-#'                materiality = 0.05)
-#' print(p1)
-#' 
-#' # ------------------------------------------------------------
-#' #              jfa Planning Summary (Frequentist)
-#' # ------------------------------------------------------------     
-#' # Input:
-#' # 
-#' # Confidence:              95% 
-#' # Materiality:             5% 
-#' # Minimum precision:       Not specified 
-#' # Likelihood:              binomial 
-#' # Expected sample errors:  6 
-#' # ------------------------------------------------------------
-#' # Output:
-#' #
-#' # Sample size:             234 
-#' # ------------------------------------------------------------
-#' # Statistics:
-#' #
-#' # Expected upper bound:    5% 
-#' # Expected precision:      2.43% 
-#' # ------------------------------------------------------------ 
-#' 
-#' # Bayesian planning with prior:
-#' 
-#' prior <- auditPrior(confidence = 0.95, likelihood = 'binomial', method = 'arm', 
-#'                     expectedError = 0.025, materiality = 0.05, cr = 0.6)
-#' 
-#' p2 <- planning(confidence = 0.95, expectedError = 0.025, materiality = 0.05,
-#'                prior = prior)
-#' print(p2)
-#' 
-#' # ------------------------------------------------------------
-#' #              jfa Planning Summary (Bayesian)
-#' # ------------------------------------------------------------
-#' # Input:
-#' # 
-#' # Confidence:              95%      
-#' # Materiality:             5% 
-#' # Minimum precision:       Not specified 
-#' # Likelihood:              binomial 
-#' # Prior distribution:      beta(2.275, 50.725) 
-#' # Expected sample errors:  4.23 
-#' # ------------------------------------------------------------
-#' # Output:
-#' #
-#' # Sample size:             169 
-#' # Posterior distribution:  beta(6.5, 215.5) 
-#' # ------------------------------------------------------------
-#' # Statistics:
-#' #
-#' # Expected upper bound:    4.99% 
-#' # Expected precision:      2.49% 
-#' # Expected Bayes factor-+: 9.32 
-#' # ------------------------------------------------------------ 
-#'
 #' @keywords planning sample size audit
 #'
+#' @examples
+#' # Frequentist planning using a binomial likelihood
+#' planning(confidence = 0.95, materiality = 0.05, expectedError = 0.025,
+#'          likelihood = 'binomial')
+#' 
+#' # Bayesian planning using a negligible beta prior
+#' planning(confidence = 0.95, materiality = 0.05, expectedError = 0.025,
+#'          likelihood = 'binomial', prior = TRUE)
+#'
 #' @export
 
-planning <- function(confidence = 0.95, expectedError = 0, likelihood = 'poisson', N = NULL, 
-                     materiality = NULL, minPrecision = NULL, 
+planning <- function(confidence, materiality = NULL, minPrecision = NULL,
+                     expectedError = 0, likelihood = 'binomial', N = NULL,  
                      prior = FALSE, nPrior = 0, kPrior = 0,
                      increase = 1, maxSize = 5000) {
   
@@ -160,7 +103,7 @@ planning <- function(confidence = 0.95, expectedError = 0, likelihood = 'poisson
   if (expectedError >= 0 && expectedError < 1) {
     errorType <- "percentage"
     if (!is.null(materiality) && expectedError >= materiality)
-      stop("This analysis is not possible: the expected errors are higher than materiality.")
+      stop("This analysis is not possible: the expected errors are higher than, or equal to, the materiality.")
   } else if (expectedError >= 1) {
     errorType <- "integer"
     if (expectedError%%1 != 0 && likelihood %in% c("binomial", "hypergeometric") && !((class(prior) == "logical" && prior == TRUE) || class(prior) == "jfaPrior"))
@@ -173,8 +116,7 @@ planning <- function(confidence = 0.95, expectedError = 0, likelihood = 'poisson
   if (is.null(minPrecision))
     minPrecision <- 1
   
-  # Calculate the sample size depending on the probability distribution
-  
+  # Requirements for the hypergeometric distribution
   if (likelihood == "hypergeometric") {
     if (is.null(N) || N <= 0)
       stop("The hypergeometric likelihood requires that you specify a population size N.")
@@ -182,7 +124,7 @@ planning <- function(confidence = 0.95, expectedError = 0, likelihood = 'poisson
       stop("The hypergeometric likelihood requires that you specify a materiality.")
     populationK <- ceiling(materiality * N)
   }
-
+  
   if (!is.null(N) && N < maxSize)
     maxSize <- N
   
@@ -217,11 +159,11 @@ planning <- function(confidence = 0.95, expectedError = 0, likelihood = 'poisson
       bound <- switch(likelihood, 
                       "poisson" = stats::qgamma(confidence, shape = 1 + kPrior + implicitK, rate = nPrior + i),
                       "binomial" = stats::qbeta(confidence, shape1 = 1 + kPrior + implicitK, shape2 = 1 + nPrior - kPrior + i - implicitK),
-                      "hypergeometric" = .qBetaBinom(p = confidence, N = N - i + implicitK, shape1 = 1 + kPrior + implicitK, shape2 = 1 + nPrior - kPrior + i - implicitK) / N)
+                      "hypergeometric" = .qBetaBinom(p = confidence, N = N - i, shape1 = 1 + kPrior + implicitK, shape2 = 1 + nPrior - kPrior + i - implicitK) / N)
       mle <- switch(likelihood,
                     "poisson" = (1 + kPrior + implicitK - 1) / (nPrior + i),
                     "binomial" = (1 + kPrior + implicitK - 1) / (1 + kPrior + implicitK + 1 + nPrior - kPrior + i - implicitK - 2),
-                    "hypergeometric" = .modeBetaBinom(N = N - i + implicitK, shape1 = 1 + kPrior + implicitK, shape2 = 1 + nPrior - kPrior + i - implicitK))
+                    "hypergeometric" = .modeBetaBinom(N = N - i, shape1 = 1 + kPrior + implicitK, shape2 = 1 + nPrior - kPrior + i - implicitK) / N)
       sufficient <- bound < materiality && (bound - mle) < minPrecision
       
     } else { # Classical planning
@@ -258,11 +200,11 @@ planning <- function(confidence = 0.95, expectedError = 0, likelihood = 'poisson
   # Create the main results object
   result <- list()
   result[["confidence"]]			<- as.numeric(confidence)
+  result[["materiality"]]  			<- as.numeric(materiality)
+  result[["minPrecision"]]			<- as.numeric(minPrecision)
   result[["expectedError"]]			<- as.numeric(expectedError)
   result[["likelihood"]]   			<- as.character(likelihood)
   result[["N"]]						<- as.numeric(N)
-  result[["materiality"]]  			<- as.numeric(materiality)
-  result[["minPrecision"]]			<- as.numeric(minPrecision)
   result[["sampleSize"]]          	<- as.numeric(ceiling(ss))
   result[["errorType"]]				<- as.character(errorType)
   result[["expectedSampleError"]]  	<- as.numeric(implicitK)
@@ -272,7 +214,7 @@ planning <- function(confidence = 0.95, expectedError = 0, likelihood = 'poisson
     result[["populationK"]]        	<- as.numeric(populationK)
   # Create the prior distribution object	
   if (((class(prior) == "logical" && prior == TRUE) || class(prior) == "jfaPrior")) {
-    if (class(prior) == "jfaPrior") {
+    if (class(prior) == "jfaPrior" && !is.null(prior[["hypotheses"]])) {
       result[["prior"]] 		  <- prior
     } else {
       result[["prior"]]           <- auditPrior(confidence = confidence, 
@@ -292,7 +234,7 @@ planning <- function(confidence = 0.95, expectedError = 0, likelihood = 'poisson
     result[["expectedPosterior"]]$posterior <- switch(likelihood, 
                                                       "poisson" = paste0("gamma(\u03B1 = ", round(result[["prior"]]$description$alpha + result[["expectedSampleError"]], 3), ", \u03B2 = ", round(result[["prior"]]$description$beta + result[["sampleSize"]], 3), ")"),
                                                       "binomial" = paste0("beta(\u03B1 = ", round(result[["prior"]]$description$alpha + result[["expectedSampleError"]], 3), ", \u03B2 = ", round(result[["prior"]]$description$beta + result[["sampleSize"]] - result[["expectedSampleError"]], 3), ")"),
-                                                      "hypergeometric" = paste0("beta-binomial(N = ", result[["N"]], ", \u03B1 = ", round(result[["prior"]]$description$alpha + result[["expectedSampleError"]], 3), ", \u03B2 = ", round(result[["prior"]]$description$beta + result[["sampleSize"]] - result[["expectedSampleError"]], 3), ")"))
+                                                      "hypergeometric" = paste0("beta-binomial(N = ", result[["N"]] - result[["sampleSize"]], ", \u03B1 = ", round(result[["prior"]]$description$alpha + result[["expectedSampleError"]], 3), ", \u03B2 = ", round(result[["prior"]]$description$beta + result[["sampleSize"]] - result[["expectedSampleError"]], 3), ")"))
     # Create the description section
     result[["expectedPosterior"]][["description"]]			<- list()
     result[["expectedPosterior"]][["description"]]$density 	<- switch(likelihood, "poisson" = "gamma", "binomial" = "beta", "hypergeometric" = "beta-binomial")
@@ -306,7 +248,7 @@ planning <- function(confidence = 0.95, expectedError = 0, likelihood = 'poisson
     result[["expectedPosterior"]][["statistics"]]$mode 		<- switch(likelihood, 
                                                                    "poisson" = (result[["expectedPosterior"]][["description"]]$alpha - 1) / result[["expectedPosterior"]][["description"]]$beta,
                                                                    "binomial" = (result[["expectedPosterior"]][["description"]]$alpha - 1) / (result[["expectedPosterior"]][["description"]]$alpha + result[["expectedPosterior"]][["description"]]$beta - 2),
-                                                                   "hypergeometric" = .modeBetaBinom(N = result[["N"]], shape1 = result[["expectedPosterior"]][["description"]]$alpha, shape2 = result[["expectedPosterior"]][["description"]]$beta))
+                                                                   "hypergeometric" = .modeBetaBinom(N = result[["N"]] - result[["sampleSize"]], shape1 = result[["expectedPosterior"]][["description"]]$alpha, shape2 = result[["expectedPosterior"]][["description"]]$beta))
     result[["expectedPosterior"]][["statistics"]]$mean 		<- switch(likelihood, 
                                                                    "poisson" = result[["expectedPosterior"]][["description"]]$alpha / result[["expectedPosterior"]][["description"]]$beta,
                                                                    "binomial" = result[["expectedPosterior"]][["description"]]$alpha / (result[["expectedPosterior"]][["description"]]$alpha + result[["expectedPosterior"]][["description"]]$beta),
@@ -314,14 +256,12 @@ planning <- function(confidence = 0.95, expectedError = 0, likelihood = 'poisson
     result[["expectedPosterior"]][["statistics"]]$median 	<- switch(likelihood, 
                                                                     "poisson" = stats::qgamma(0.5, shape = result[["expectedPosterior"]][["description"]]$alpha, rate = result[["expectedPosterior"]][["description"]]$beta),
                                                                     "binomial" = stats::qbeta(0.5, shape1 = result[["expectedPosterior"]][["description"]]$alpha, shape2 = result[["expectedPosterior"]][["description"]]$beta),
-                                                                    "hypergeometric" = .qBetaBinom(0.5, N = result[["N"]], shape1 = result[["expectedPosterior"]][["description"]]$alpha, shape2 = result[["expectedPosterior"]][["description"]]$beta))
+                                                                    "hypergeometric" = .qBetaBinom(0.5, N = result[["N"]] - result[["sampleSize"]], shape1 = result[["expectedPosterior"]][["description"]]$alpha, shape2 = result[["expectedPosterior"]][["description"]]$beta))
     result[["expectedPosterior"]][["statistics"]]$ub 		<- switch(likelihood, 
                                                                  "poisson" = stats::qgamma(confidence, shape = result[["expectedPosterior"]][["description"]]$alpha, rate = result[["expectedPosterior"]][["description"]]$beta),
                                                                  "binomial" = stats::qbeta(confidence, shape1 = result[["expectedPosterior"]][["description"]]$alpha, shape2 = result[["expectedPosterior"]][["description"]]$beta),
-                                                                 "hypergeometric" = .qBetaBinom(confidence, N = result[["N"]], shape1 = result[["expectedPosterior"]][["description"]]$alpha, shape2 = result[["expectedPosterior"]][["description"]]$beta))									
-    result[["expectedPosterior"]][["statistics"]]$precision <- ifelse(likelihood == "hypergeometric", 
-                                                                      yes = (result[["expectedPosterior"]][["statistics"]]$ub - result[["expectedPosterior"]][["statistics"]]$mode) / result[["N"]],
-                                                                      no = result[["expectedPosterior"]][["statistics"]]$ub - result[["expectedPosterior"]][["statistics"]]$mode)
+                                                                 "hypergeometric" = .qBetaBinom(confidence, N = result[["N"]] - result[["sampleSize"]], shape1 = result[["expectedPosterior"]][["description"]]$alpha, shape2 = result[["expectedPosterior"]][["description"]]$beta))									
+    result[["expectedPosterior"]][["statistics"]]$precision <- result[["expectedPosterior"]][["statistics"]]$ub - result[["expectedPosterior"]][["statistics"]]$mode
     # Create the hypotheses section
     if (result[["materiality"]] != 1) {
       result[["expectedPosterior"]][["hypotheses"]] 			<- list()
@@ -329,20 +269,20 @@ planning <- function(confidence = 0.95, expectedError = 0, likelihood = 'poisson
       result[["expectedPosterior"]][["hypotheses"]]$pHmin 		<- switch(likelihood, 
                                                                       "poisson" = stats::pgamma(materiality, shape = result[["expectedPosterior"]][["description"]]$alpha, rate = result[["expectedPosterior"]][["description"]]$beta),
                                                                       "binomial" = stats::pbeta(materiality, shape1 = result[["expectedPosterior"]][["description"]]$alpha, shape2 = result[["expectedPosterior"]][["description"]]$beta),
-                                                                      "hypergeometric" = .pBetaBinom(ceiling(materiality * result[["N"]]), N = result[["N"]], shape1 = result[["expectedPosterior"]][["description"]]$alpha, shape2 = result[["expectedPosterior"]][["description"]]$beta))
+                                                                      "hypergeometric" = .pBetaBinom(ceiling(materiality * result[["N"]]), N = result[["N"]] - result[["sampleSize"]], shape1 = result[["expectedPosterior"]][["description"]]$alpha, shape2 = result[["expectedPosterior"]][["description"]]$beta))
       result[["expectedPosterior"]][["hypotheses"]]$pHplus 		<- switch(likelihood, 
                                                                        "poisson" = stats::pgamma(materiality, shape = result[["expectedPosterior"]][["description"]]$alpha, rate = result[["expectedPosterior"]][["description"]]$beta, lower.tail = FALSE),
                                                                        "binomial" = stats::pbeta(materiality, shape1 = result[["expectedPosterior"]][["description"]]$alpha, shape2 = result[["expectedPosterior"]][["description"]]$beta, lower.tail = FALSE),
-                                                                       "hypergeometric" = 1 - result[["expectedPosterior"]][["hypotheses"]]$pHmin)
+                                                                       "hypergeometric" = .pBetaBinom(ceiling(materiality * result[["N"]]), N = result[["N"]] - result[["sampleSize"]], shape1 = result[["expectedPosterior"]][["description"]]$alpha, shape2 = result[["expectedPosterior"]][["description"]]$beta, lower.tail = FALSE))
       result[["expectedPosterior"]][["hypotheses"]]$oddsHmin 	<- result[["expectedPosterior"]][["hypotheses"]]$pHmin / result[["expectedPosterior"]][["hypotheses"]]$pHplus
       result[["expectedPosterior"]][["hypotheses"]]$oddsHplus 	<- 1 / result[["expectedPosterior"]][["hypotheses"]]$oddsHmin
       result[["expectedPosterior"]][["hypotheses"]]$expectedBf 	<- result[["expectedPosterior"]][["hypotheses"]]$oddsHmin / result[["prior"]][["hypotheses"]]$oddsHmin
     }
     result[["expectedPosterior"]][["N"]] <- result[["N"]]
-    # Add class 'jfaPosterior' to the expected posterior distribution object.
+    # Add class 'jfaPosterior' to the expected posterior distribution object
     class(result[["expectedPosterior"]]) <- "jfaPosterior"
   }
-  # Add class 'jfaPlanning' to the result.
+  # Add class 'jfaPlanning' to the result
   class(result) <- "jfaPlanning"
   return(result)
 }
\ No newline at end of file
