@@ -1,4 +1,4 @@
-context("1. Consistency test for function auditPrior()")
+context("1. Test consistency of function auditPrior()")
 
 # jfa version 0.2.0
 
@@ -19,15 +19,15 @@ test_that(desc = "(id: f4-v0.1.0-t1) Test for method = 'none'", {
 test_that(desc = "(id: f4-v0.1.0-t2) Test for method = 'median'", {
   prior <- auditPrior(confidence = 0.95, likelihood = "binomial", method = "median", materiality = 0.05)
   expect_equal(prior[["description"]]$alpha, 1)
-  expect_equal(prior[["description"]]$beta, 13.513, tolerance = 0.001)
+  expect_equal(prior[["description"]]$beta, 13.51341, tolerance = 0.001)
   
   prior <- auditPrior(confidence = 0.95, likelihood = "binomial", method = "median", expectedError = 0.02, materiality = 0.05)
-  expect_equal(prior[["description"]]$alpha, 1.4, tolerance = 0.001)
-  expect_equal(prior[["description"]]$beta, 20.6, tolerance = 0.001)
+  expect_equal(prior[["description"]]$alpha, 1.4114, tolerance = 0.001)
+  expect_equal(prior[["description"]]$beta, 21.1586, tolerance = 0.001)
   
-  prior <- auditPrior(confidence = 0.95, likelihood = "poisson", method = "median", ir = 0.6, cr = 0.6, materiality = 0.05, )
+  prior <- auditPrior(confidence = 0.95, likelihood = "poisson", method = "median", materiality = 0.05)
   expect_equal(prior[["description"]]$alpha, 1)
-  expect_equal(prior[["description"]]$beta, 13.863, tolerance = 0.001)  
+  expect_equal(prior[["description"]]$beta, 13.86294, tolerance = 0.001)  
 })
 
 test_that(desc = "(id: f4-v0.1.0-t3) Test for method = 'hypotheses'", {
@@ -55,7 +55,7 @@ test_that(desc = "(id: f4-v0.1.0-t4) Test for method = 'arm'", {
   
   prior <- auditPrior(materiality = 0.05, confidence = 0.95, method = "arm", likelihood = "hypergeometric", ir = 0.6, cr = 0.6, N = 3500)
   expect_equal(prior[["description"]]$alpha, 1)
-  expect_equal(prior[["description"]]$beta, 20, tolerance = 0.001)
+  expect_equal(prior[["description"]]$beta, 21, tolerance = 0.001)
 })
 
 test_that(desc = "(id: f4-v0.1.0-t5) Test for method = 'sample'", {
@@ -96,20 +96,20 @@ test_that(desc = "(id: f4-v0.1.0-t6) Test for method = 'factor'", {
 
 test_that(desc = "(id: f4-v0.4.0-t1) Test for method = 'median' with expected errors > 0", {
   prior <- auditPrior(materiality = 0.05, confidence = 0.95, method = "median", likelihood = "binomial", expectedError = 0.01)
-  expect_equal(prior[["description"]]$alpha, 1.15, tolerance = 0.001)
-  expect_equal(prior[["description"]]$beta, 15.85, tolerance = 0.001)
+  expect_equal(prior[["description"]]$alpha, 1.1554, tolerance = 0.001)
+  expect_equal(prior[["description"]]$beta, 16.3846, tolerance = 0.001)
   
   prior <- auditPrior(materiality = 0.05, confidence = 0.95, method = "median", likelihood = "binomial", expectedError = 0.025)
-  expect_equal(prior[["description"]]$alpha, 1.6, tolerance = 0.001)
-  expect_equal(prior[["description"]]$beta, 24.4, tolerance = 0.001)
+  expect_equal(prior[["description"]]$alpha, 1.6146, tolerance = 0.001)
+  expect_equal(prior[["description"]]$beta, 24.9694, tolerance = 0.001)
   
   prior <- auditPrior(materiality = 0.05, confidence = 0.95, method = "median", likelihood = "poisson", expectedError = 0.01)
-  expect_equal(prior[["description"]]$alpha, 1.171, tolerance = 0.001)
-  expect_equal(prior[["description"]]$beta, 17.1, tolerance = 0.001)
+  expect_equal(prior[["description"]]$alpha, 1.1722, tolerance = 0.001)
+  expect_equal(prior[["description"]]$beta, 17.22, tolerance = 0.001)
   
   prior <- auditPrior(materiality = 0.05, confidence = 0.95, method = "median", likelihood = "poisson", expectedError = 0.025)
-  expect_equal(prior[["description"]]$alpha, 1.668, tolerance = 0.001)
-  expect_equal(prior[["description"]]$beta, 26.72, tolerance = 0.001)
+  expect_equal(prior[["description"]]$alpha, 1.681, tolerance = 0.001)
+  expect_equal(prior[["description"]]$beta, 27.24, tolerance = 0.001)
 })
 
 # jfa version 0.5.0
@@ -139,4 +139,32 @@ test_that(desc = "(id: f4-v0.5.0-t2) Test for plot function", {
 # No changes to be benchmarked
 
 # jfa version 0.5.2
-# No changes to be benchmarked
\ No newline at end of file
+# No changes to be benchmarked
+
+# jfa version 0.5.3
+
+test_that(desc = "(id: f4-v0.5.3-t1) Test for bram method binomial", {
+  N <- 20000
+  materiality <- 2000
+  expectedMisstatement <- 300
+  expectedUpperBound <- 5000
+  ub <- expectedUpperBound / N
+  theta <- materiality / N
+  expectedError <- expectedMisstatement / N
+  prior <- auditPrior(confidence = 0.95, materiality = theta, likelihood = "binomial", method = "bram", expectedError = expectedError, ub = ub)
+  expect_equal(prior[["description"]]$alpha, 1.1581)
+  expect_equal(prior[["description"]]$beta, 11.3819)
+})
+
+test_that(desc = "(id: f4-v0.5.3-t2) Test for bram method poisson", {
+  N <- 20000
+  materiality <- 2000
+  expectedMisstatement <- 300
+  expectedUpperBound <- 5000
+  ub <- expectedUpperBound / N
+  theta <- materiality / N
+  expectedError <- expectedMisstatement / N
+  prior <- auditPrior(confidence = 0.95, materiality = theta, likelihood = "poisson", method = "bram", expectedError = expectedError, ub = ub)
+  expect_equal(prior[["description"]]$alpha, 1.20259, tolerance = 0.00001)
+  expect_equal(prior[["description"]]$beta, 13.50597, tolerance = 0.00001)
+})
\ No newline at end of file
